// Copyright (c) 2023 Tudor Stanciu

import { camelizeKeys } from "../../data/camelizer";

describe("camelizeKeys", () => {
  it("should camelize object keys", () => {
    const obj = {
      Test1: "value",
      Test2: {
        Value: "nested_value"
      }
    };
    const expected = {
      test1: "value",
      test2: {
        value: "nested_value"
      }
    };
    const actual = camelizeKeys(obj);
    expect(actual).toEqual(expected);
  });

  it("should not modify non-object values", () => {
    const str = "test_string";
    const num = 123;
    expect(camelizeKeys(str)).toBe(str);
    expect(camelizeKeys(num)).toBe(num);
  });

  it("should camelize object keys in an array", () => {
    const arr = [
      {
        Test1: "value"
      },
      {
        Test2: {
          Value: "nested_value"
        }
      }
    ];
    const expected = [
      {
        test1: "value"
      },
      {
        test2: {
          value: "nested_value"
        }
      }
    ];

    const actual = camelizeKeys(arr);
    expect(actual).toEqual(expected);
  });

  it("should handle null and undefined values", () => {
    expect(camelizeKeys(null)).toBe(null);
    expect(camelizeKeys(undefined)).toBe(undefined);
  });
});
