// Copyright (c) 2023 Tudor Stanciu

import { isArray, isObject, isJson } from "../../data/typeValidator";

describe("isArray", () => {
  it("should return true when given an array", () => {
    expect(isArray([])).toBe(true);
  });

  it("should return false when given a non-array", () => {
    expect(isArray(123)).toBe(false);
    expect(isArray("foo")).toBe(false);
    expect(isArray({})).toBe(false);
    expect(isArray(null)).toBe(false);
    expect(isArray(undefined)).toBe(false);
  });
});

describe("isObject", () => {
  it("should return true when given an object", () => {
    expect(isObject({})).toBe(true);
    expect(isObject({ foo: "bar" })).toBe(true);
  });

  it("should return false when given a non-object", () => {
    expect(isObject(123)).toBe(false);
    expect(isObject("foo")).toBe(false);
    expect(isObject([])).toBe(false);
    expect(isObject(null)).toBe(false);
    expect(isObject(undefined)).toBe(false);
  });
});

describe("isJson", () => {
  it("should return success: true and the parsed data when given valid JSON", () => {
    const input = '{"foo": "bar"}';
    const expectedOutput = { success: true, data: { foo: "bar" } };
    expect(isJson(input)).toEqual(expectedOutput);
  });

  it("should return success: false and null when given invalid JSON", () => {
    const input = '{foo: "bar"}';
    const expectedOutput = { success: false, data: null };
    expect(isJson(input)).toEqual(expectedOutput);
  });
});
