// Copyright (c) 2023 Tudor Stanciu

interface ObjectWithAnyKey {
  [key: string]: any;
}

function camelizeKeys(o: any): any {
  if (!o || (typeof o !== "object" && !Array.isArray(o))) return o;
  let newO, value;
  if (o instanceof Array) {
    return o.map(function (value) {
      if (typeof value === "object") {
        value = camelizeKeys(value);
      }
      return value;
    });
  } else {
    newO = {} as ObjectWithAnyKey;
    for (const origKey in o) {
      if (Object.prototype.hasOwnProperty.call(o, origKey)) {
        const newKey = (
          origKey.charAt(0).toLowerCase() + origKey.slice(1) || origKey
        ).toString();
        value = o[origKey];
        if (
          value instanceof Array ||
          (value !== null && value.constructor === Object)
        ) {
          value = camelizeKeys(value);
        }
        newO[newKey] = value;
      }
    }
  }
  return newO;
}

export { camelizeKeys };
