// Copyright (c) 2023 Tudor Stanciu

import { isArray, isObject, isJson } from "../data/typeValidator";

const setItem = (key: string, value: any): void => {
  let valueToStore = value;
  if (isArray(value) || isObject(value)) {
    valueToStore = JSON.stringify(value);
  }

  window.localStorage.setItem(key, valueToStore);
};

const getItem = (key: string): any => {
  const value = window.localStorage.getItem(key);
  if (value === null) return null;
  const { data, success } = isJson(value);
  return success ? data : value;
};

const removeItem = (key: string): void => {
  window.localStorage.removeItem(key);
};

const clear = (): void => {
  window.localStorage.clear();
};

const getKey = (index: number): string | null => {
  const keyName = window.localStorage.key(index);
  return keyName;
};

const localStorage = { setItem, getItem, removeItem, clear, getKey };

export { setItem, getItem, removeItem, clear, getKey };
export default localStorage;
